Struct aptos_crypto::multi_ed25519::MultiEd25519Signature
source · [−]pub struct MultiEd25519Signature { /* private fields */ }Expand description
Vector of the multi-key signatures along with a 32bit [u8; 4] bitmap required to map signatures with their corresponding public keys.
Note that bits are read from left to right. For instance, in the following bitmap [0b0001_0000, 0b0000_0000, 0b0000_0000, 0b0000_0001], the 3rd and 31st positions are set.
Implementations
sourceimpl MultiEd25519Signature
impl MultiEd25519Signature
sourcepub fn new(
signatures: Vec<(Ed25519Signature, u8)>
) -> Result<Self, CryptoMaterialError>
pub fn new(
signatures: Vec<(Ed25519Signature, u8)>
) -> Result<Self, CryptoMaterialError>
This method will also sort signatures based on index.
sourcepub fn new_with_signatures_and_bitmap(
signatures: Vec<Ed25519Signature>,
bitmap: [u8; 4]
) -> Self
pub fn new_with_signatures_and_bitmap(
signatures: Vec<Ed25519Signature>,
bitmap: [u8; 4]
) -> Self
Creates a new MultiEd25519signature by given signatures and bitmap.
sourcepub fn signatures(&self) -> &Vec<Ed25519Signature>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
pub fn signatures(&self) -> &Vec<Ed25519Signature>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
Getter signatures.